@@ -9,6 +9,7 @@ import jenkins
 import json
 import logging
 import os
+import re
 import requests
 from stevedore import driver, ExtensionManager
 import xml.etree.ElementTree as ET
@@ -89,6 +90,10 @@ jenkins.Jenkins.get_build_stages = get_build_stages
 LOGGER = logging.getLogger(__name__)
 
 
+class JenkinsCollectError(Exception):
+    pass
+
+
 class EsLogger(object):
     # Initialise the object
     def __init__(self, console_length, targets):
@@ -101,7 +106,7 @@ class EsLogger(object):
 
         self.es_job_name = None
         self.es_build_number = None
-        self.build_info_fields = ['description', 'number', 'url']
+        self.build_info_fields = ['description', 'number', 'result', 'url']
 
         self.es_info = {}
         self.es_info['test_report'] = None
@@ -197,8 +202,9 @@ class EsLogger(object):
 
     # List all of the plugins we know about
     @staticmethod
-    def list_plugins(data_only=False, namespaces=['gather_build_data', 'console_log_processor',
-                                                  'event_generator', 'event_target']):
+    def list_plugins(data_only=False,
+                     namespaces=['gather_build_data', 'console_log_processor', 'event_generator',
+                                 'event_generator.console_log_events', 'event_target']):
         def print_plugin(ext):
             print("\t{}".format(ext.entry_point.name))
 
@@ -238,9 +244,12 @@ class EsLogger(object):
         self.es_info[self.data_name]['jenkins_url'] = self.jenkins_url
         self.es_info[self.data_name]['build_number'] = self.es_build_number
 
-        # Build Info (Parameters, Status)
-        self.build_info = self.server.get_build_info(self.es_job_name, self.es_build_number,
-                                                     depth=0)
+        try:
+            # Build Info (Parameters, Status)
+            self.build_info = self.server.get_build_info(self.es_job_name, self.es_build_number,
+                                                         depth=0)
+        except Exception as exc:
+            raise JenkinsCollectError("get_build_info") from exc
         self.es_info['build_info'] = self.build_info
 
         try:
@@ -250,6 +259,8 @@ class EsLogger(object):
                     jenkins_err))
             self.es_info['job_config_info'] = None
             self.es_info['job_config_info_status'] = "Unable to retrieve config.xml."
+        except Exception as exc:
+            raise JenkinsCollectError("get_job_config") from exc
 
         if self.job_xml_raw is not None:
             self.job_xml = ET.fromstring(self.job_xml_raw)
@@ -257,7 +268,10 @@ class EsLogger(object):
             self.es_info['job_config_info_status'] = "Retrieved config.xml."
 
         # Environment Variables
-        self.env_vars = self.server.get_build_env_vars(self.es_job_name, self.es_build_number)
+        try:
+            self.env_vars = self.server.get_build_env_vars(self.es_job_name, self.es_build_number)
+        except Exception as exc:
+            raise JenkinsCollectError("get_build_env_vars") from exc
         self.es_info['env_vars'] = self.env_vars
 
         # Process build_info
@@ -352,8 +366,27 @@ class EsLogger(object):
 
     # Process Console Log
     def process_console_log(self):
-        self.console_log = self.server.get_build_console_output(self.es_job_name,
-                                                                self.es_build_number)
+        try:
+            self.console_log_ts = self.server.get_build_console_output(self.es_job_name,
+                                                                       self.es_build_number)
+        except Exception as exc:
+            raise JenkinsCollectError("get_build_console_output") from exc
+        # Because of timestamper 1.9+
+        # https://issues.jenkins-ci.org/browse/JENKINS-48344
+        # if the line starts with the timestamp, strip it
+        # [2020-04-22T11:21:48.848Z] console log
+        all_lines = []
+        time_re = re.compile(
+                r'(^\[[0-9]{4}-[0-9]{2}-[0-9]{2}' +                 # Date: '[2020-04-22'
+                r'T[0-9]{2}:[0-9]{2}:[0-9]{2}\.[0-9]{3}Z\]\s)' +    # Time: 'T11:21:48.848Z] '
+                r'(.*$)')                                           # Actual console log line
+        for line in self.console_log_ts.splitlines():
+            mo = time_re.match(line)
+            if mo:
+                all_lines.append(mo.group(2))
+            else:
+                all_lines.append(line)
+        self.console_log = "\n".join(all_lines)
 
         # Add plugin loading and processing with an array of plugins
         # e.g. - count errors, count warnings, parse test results, etc.
@@ -434,14 +467,20 @@ class EsLogger(object):
 
     def get_test_report(self):
         if self.es_info['test_report'] is None:
-            self.es_info['test_report'] = self.server.get_build_test_report(
-                self.es_job_name, self.es_build_number)
+            try:
+                self.es_info['test_report'] = self.server.get_build_test_report(
+                    self.es_job_name, self.es_build_number)
+            except Exception as exc:
+                raise JenkinsCollectError("get_build_test_report") from exc
         return self.es_info['test_report']
 
     def get_stages(self):
         if self.es_info['stages'] is None:
-            self.es_info['stages'] = self.server.get_build_stages(
-                self.es_job_name, self.es_build_number)
+            try:
+                self.es_info['stages'] = self.server.get_build_stages(
+                    self.es_job_name, self.es_build_number)
+            except Exception as exc:
+                raise JenkinsCollectError("get_build_stages") from exc
         return self.es_info['stages']
 
     # Dump the string
