@@ -4,11 +4,11 @@
 __author__ = 'jonpsull'
 
 import es_logger
+import importlib.metadata
 import io
 from jenkins import JenkinsException, NotFoundException
 import nose
 from parameterized import parameterized
-import pkg_resources
 import requests
 from stevedore import ExtensionManager
 import unittest.mock
@@ -26,14 +26,11 @@ class TestEsLogger(object):
                        'gather_build_data1 gather_build_data2 gather_build_data3',
                        'GENERATE_EVENTS': 'generate_events1 generate_events2 generate_events3'})
     def setup(self):
-        dep = pkg_resources.EntryPoint.parse(
-            'dummy = test.test_plugins:DummyEventTarget')
-        d = pkg_resources.Distribution()
-        d._ep_map = {'es_logger.plugins.event_target': {'dummy': dep}}
-        pkg_resources.working_set.add(d, 'dummy')
-        ExtensionManager.ENTRY_POINT_CACHE = {}
-
+        dummy_ep = importlib.metadata.EntryPoint(
+            'dummy', 'test.test_plugins:DummyEventTarget', 'es_logger.plugins.event_target')
+        ExtensionManager.ENTRY_POINT_CACHE = {'es_logger.plugins.event_target': [dummy_ep]}
         self.esl = es_logger.EsLogger(1000, ['dummy'])
+
         self.urls = {
             'get_build_artifact': 'jenkins_url/job/job_name/1/artifact/1',
             'get_build_stages': 'jenkins_url/job/job_name/1/wfapi/describe/'}
@@ -153,22 +150,36 @@ class TestEsLogger(object):
                            "{} returned {} not {}".format(getter.__name__, getter(), expected))
 
     def test_list_plugins(self):
-        dep = pkg_resources.EntryPoint.parse(
-            'dummy = test.test_plugins:DummyConsoleLogProcessor')
-        d = pkg_resources.Distribution()
-        d._ep_map = {'es_logger.plugins.console_log_processor': {'dummy': dep}}
-        pkg_resources.working_set.add(d, 'dummy')
-        ExtensionManager.ENTRY_POINT_CACHE = {}
-        self.esl.list_plugins()
+        expected = '''es_logger.plugins.gather_build_data:
+\tNone found
+es_logger.plugins.console_log_processor:
+\tNone found
+es_logger.plugins.event_generator:
+\tansible_fatal
+\tansible_recap_v2
+\tcommit
+\tconsole_log_events
+\tjunit
+\tstages
+es_logger.plugins.event_generator.console_log_events:
+\tansible
+\tes_logger
+es_logger.plugins.event_target:
+\tdummy
+'''
+        with unittest.mock.patch('sys.stdout', new_callable=io.StringIO) as mock_stdout:
+            es_logger.EsLogger.list_plugins()
+        nose.tools.ok_(mock_stdout.getvalue() == expected,
+                       "Output was:\n{}".format(mock_stdout.getvalue()))
 
     def test_list_plugins_data_only(self):
-        dep = pkg_resources.EntryPoint.parse(
-            'dummy = test.test_plugins:DummyConsoleLogProcessor')
-        d = pkg_resources.Distribution()
-        d._ep_map = {'es_logger.plugins.console_log_processor': {'dummy': dep}}
-        pkg_resources.working_set.add(d, 'dummy')
-        ExtensionManager.ENTRY_POINT_CACHE = {}
-        self.esl.list_plugins(True, 'console_log_processor')
+        dummy_ep = importlib.metadata.EntryPoint(
+            'dummy', 'test.test_plugins:DummyConsoleLogProcessor',
+            'es_logger.plugins.console_log_processor')
+        ExtensionManager.ENTRY_POINT_CACHE = {'es_logger.plugins.console_log_processor': [dummy_ep]}
+        plugins = es_logger.EsLogger.list_plugins(True, ['console_log_processor'])
+        expected = ['dummy']
+        nose.tools.ok_(plugins == expected, "Output was: {}, expected {}".format(plugins, expected))
 
     def test_get_build_data(self):
         # Recreate the esl to validate parameters aren't set
@@ -562,11 +573,11 @@ class TestEsLogger(object):
         self.esl.process_console_logs = ['dummy']
         with unittest.mock.patch('stevedore.driver.DriverManager') as mock_driver_mgr:
             with unittest.mock.patch('jenkins.Jenkins.get_build_console_output') as mock_get:
-                mock_get.return_value = 'log'
+                mock_get.return_value = 'log\n[2020-04-22T11:21:48.848Z] log2 words\nlog3'
                 self.esl.process_console_log()
                 mock_driver_mgr.assert_called_once()
                 self.esl.console_length = 1
-                mock_get.return_value = 'log'
+                mock_get.return_value = 'log\nlog2 words\nlog3'
                 self.esl.process_console_log()
                 nose.tools.ok_(len(self.esl.es_info['console_log']) == 1,
                                "Console log length not 1: {}".format(
@@ -584,6 +595,7 @@ class TestEsLogger(object):
                                                    'dummy': 'dummy'}}
         self.esl.es_info['build_info'] = {'description': 'description',
                                           'number': '1',
+                                          'result': 'SUCCESS',
                                           'url': 'url'}
         self.esl.es_info['parameters'] = {'parameter': 'parameter'}
         self.esl.es_info[self.esl.data_name]['job_name'] = 'job_name'
@@ -666,3 +678,32 @@ class TestEsLogger(object):
         self.esl.targets = [mock_target, mock_target]
         status = self.esl.finish()
         nose.tools.ok_(status == 2)
+
+    @parameterized.expand(['get_build_data', 'process_console_log', 'get_test_report',
+                           'get_stages'])
+    def test_exception_wraps(self, param):
+        with unittest.mock.patch('es_logger.jenkins.Jenkins.jenkins_open') as mock_open:
+            mock_open.return_value = None
+            self.esl.server.crumb = False
+            func = getattr(self.esl, param)
+            nose.tools.assert_raises(es_logger.JenkinsCollectError, func)
+
+    # Needs a slightly different flow because 2nd call in the get_build_data function
+    # Although the same outcome, ensures coverage, so is testing the right spot
+    def test_exception_wraps_get_build_data(self):
+        with unittest.mock.patch('es_logger.jenkins.Jenkins.jenkins_open') as mock_open, \
+                unittest.mock.patch('jenkins.Jenkins.get_build_info') as mock_build_info:
+            mock_build_info.return_value = {}
+            mock_open.return_value = None
+            self.esl.server.crumb = False
+            nose.tools.assert_raises(es_logger.JenkinsCollectError, self.esl.get_build_data)
+
+    # Needs a slightly different flow because get_job_config needs to throw a non-Jenkins error
+    # Although the same outcome, ensures coverage, so is testing the right spot
+    def test_exception_wraps_get_job_config(self):
+        with unittest.mock.patch('es_logger.jenkins.Jenkins.jenkins_open') as mock_open, \
+                unittest.mock.patch('jenkins.Jenkins.get_build_info') as mock_build_info:
+            mock_build_info.return_value = {}
+            mock_open.side_effect = Exception("Wrap me")
+            self.esl.server.crumb = False
+            nose.tools.assert_raises(es_logger.JenkinsCollectError, self.esl.get_build_data)
